@@ -14,7 +14,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(get_performance_probability);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -22,7 +22,7 @@ Performance::Probability - The performance probability is a likelihood measure o
 
 =head1 VERSION
 
-0.02
+0.03
 
 =head1 SYNOPSYS
 
@@ -149,27 +149,30 @@ sub _covariance {
                 $sell_i  = $sell_time->[$i];
                 $sell_j  = $sell_time->[$j];
 
-                if ($start_j > $start_i and $start_j < $sell_i) {
-                    #calculate a, b and c interval. please see the documentation for details
-                    #of a, b and c.
-                    my $a_interval = $start_j - $start_i;
-                    my $b_interval = $sell_i - $start_j;
-                    my $c_interval = $sell_j - $sell_i;
+                my $min_end_time   = $sell_time->[$i] < $sell_time->[$j]   ? $sell_time->[$i]  : $sell_time->[$j];
+                my $max_start_time = $start_time->[$i] > $start_time->[$j] ? $start_time->[$i] : $start_time->[$j];
+                my $b_interval     = $max_start_time - $min_end_time;
 
-                    if ($c_interval < 0) {
-                        $c_interval = 0 - $c_interval;
-                        $b_interval = $sell_j - $start_i;
-                    }
+                if ($b_interval > 0) {
+                    #if ($start_j > $start_i and $start_j < $sell_i) {
+                    #calculate first and second contracts durations. please see the documentation for details
+
+                    my $first_contract_duration  = ($sell_time->[$i] - $start_time->[$i]);
+                    my $second_contract_duration = ($sell_time->[$j] - $start_time->[$j]);
 
                     my $i_strike = 0.0 - Math::Gauss::XS::inv_cdf($pk->[$i]);
                     my $j_strike = 0.0 - Math::Gauss::XS::inv_cdf($pk->[$j]);
 
-                    my $corr_ij = $b_interval / (sqrt($a_interval + $b_interval) * sqrt($b_interval + $c_interval));
+                    my $corr_ij = $b_interval / (sqrt($first_contract_duration) * sqrt($second_contract_duration));
 
                     if ($types->[$i] ne $types->[$j]) {
                         $corr_ij = -1 * $corr_ij;
                     }
 
+                    if ($corr_ij < -1 or $corr_ij > 1) {
+                        next;
+                    }
+
                     my $p_ij = Math::BivariateCDF::bivnor($i_strike, $j_strike, $corr_ij);
 
                     my $covariance_ij =
@@ -212,6 +215,13 @@ sub get_performance_probability {
         die "start_time, sell_time, types, underlying, bought_price and payout are required parameters and need to be arrays of same lengths.";
     }
 
+    my $i = 0;
+    for ($i = 0; $i < @{$start_time}; ++$i) {
+        if ($sell_time->[$i] - $start_time->[$i] == 0) {
+            die "Contract duration ( sell_time minus start_time ) cannot be zero.";
+        }
+    }
+
     my $pk = _build_pk($bought_price, $payout);
     my $lk = _build_lk($bought_price);
     my $wk = _build_wk($bought_price, $payout);
